@@ -5,7 +5,7 @@ from django.contrib.staticfiles.finders import BaseStorageFinder
 class LessFinder(BaseStorageFinder):
     """
     A staticfiles finder that looks in LESS_ROOT
-    for compressed files, to be used during development
+    for compiled files, to be used during development
     with staticfiles development file server or during
     deployment.
     """
